// In diesem Beispiel wird der Arduino als Webserver verwendet.
// Eine HTML-Seite wird geschrieben, die die ausgelesenen Daten
// anzeigt und die Dateneingabe mit sechs Buttons ermöglicht

#include <Servo.h>    // Servo-Library importieren
#include <SPI.h>      // SPI-Library importieren (für Serielle Schnittstelle)
#include <Ethernet.h> // Ethernet-Library importieren (für Ethernet-Schnittstelle)

//Hub (Intern) Netzwerkeinstellungen
//byte mac[] = { 0x90, 0xA2, 0xDA, 0x00, 0x82, 0xCC }; // MAC-Adresse des Ethernet-Shields
//byte ip[] = { 192, 168, 14, 10 };                    // IP-Adresse des Arduinos
//byte gateway[] = { 192, 168, 14, 254 };              // Netzwerk-Gateway für das interne Netzwerk
//byte subnet[]  = { 255, 255, 255, 0 };               // Subnetz-Maske für das interne Netzwerk

//ZUHAUS Netzwerkeinstellungen
byte mac[] = { 0x90, 0xA2, 0xDA, 0x00, 0x82, 0xCC }; // MAC-Adresse des Ethernet-Shields
byte ip[] = { 192, 168, 178, 222 };                  // IP-Adresse des Arduinos
byte gateway[] = { 192, 168, 178, 1 };               // Netzwerk-Gateway für das interne Netzwerk
byte subnet[]  = { 255, 255, 255, 0 };               // Subnetz-Maske für das interne Netzwerk

int sensorPin = 0;   // Poti-Pin ("Temperaturmessung")
int servoPin = 9;    // Servo-Pin ("Heizungssteuerung")

int servoRot = 0;    // Variable zum Speichern der Servo-Rotation ("Heizstufe")
int tmpValue = 0;    // Variable zum Speichern der aktuellen "Temperatur"

Server server(80);   // Server-Objekt, um Arduino als Webserver zu verwenden
Servo servo;         // Servo-Objekt zum Steuern des Servos

int msgLength = 100;                 // maximale Länge der zu übertragenden Nachrichten (HTTP-Request)
String readString = String(msgLength);  // Variable zum Speichern von Client-Anfragen (HTTP-Requests)

void setup()
{
  Ethernet.begin(mac, ip, gateway, subnet);  // Ethernet-Verbindung starten
  server.begin();  // Server-Funktionen starten
  
  servo.attach(servoPin);  // Servo am Servo-Pin aktivieren

  Serial.begin(9600); // Serielle Übertragung starten
}

void loop()
{
  Client client = server.available();  // potentiell verbundenen Client speichern
  
  if (client)  // wenn ein Client verbunden ist
  {
    while (client.connected()) // solang der Client verbunden ist
    {
      if (client.available())  // wenn der Client eine Nachricht gesendet hat
      {
        char c = client.read(); // lies das nächste byte der Nachricht ein
  
        if (readString.length() < msgLength) // solange die Nachricht kürzer als maximale Zeichenzahl ist
        {
          readString = readString + c; // hänge das eingelesene Zeichen an readString an
        }

        if (c == '\n')  // wenn Zeilenumbruch erreicht ist (Ende des HTTP-Requests)
        {  
          tmpValue = analogRead(sensorPin); // Temperatur vom Sensor-Pin auslesen und in tmpValue speichern
          
          if(readString.indexOf("Temperatur=0") > -1) // wenn die eingelesene Nachricht die Zeichenkette "Temperatur=0" enthält
          {
            servo.write(0);
          }
          
          if(readString.indexOf("Temperatur=1") > -1) // wenn die eingelesene Nachricht die Zeichenkette "Temperatur=1" enthält
          {
            servo.write(30); // den Servo auf 30 Grad drehen
          }
          
          if(readString.indexOf("Temperatur=2") > -1) // wenn die eingelesene Nachricht die Zeichenkette "Temperatur=2" enthält
          {
            servo.write(60); // den Servo auf 60 Grad drehen
          }
          
          if(readString.indexOf("Temperatur=3") > -1) // wenn die eingelesene Nachricht die Zeichenkette "Temperatur=3" enthält
          {
            servo.write(90); // den Servo auf 90 Grad drehen
          }
          
          if(readString.indexOf("Temperatur=4") > -1) // wenn die eingelesene Nachricht die Zeichenkette "Temperatur=4" enthält
          {
            servo.write(120); // den Servo auf 120 Grad drehen
          }
          
          if(readString.indexOf("Temperatur=5") > -1) // wenn die eingelesene Nachricht die Zeichenkette "Temperatur=5" enthält
          {
            servo.write(150); // den Servo auf 150 Grad drehen
          }
          
          client.println("HTTP/1.1 200 OK"); // Dokumenttyp-Deklaration für HTML-Datei
          client.println("Content-Type: text/html"); // Dokumenttyp-Deklaration für HTML-Datei
          client.println();
          client.print("<html>"); // Start-Tag für HTML-Datei
          client.print("<head>"); // Start-Tag für Header
          client.print("<title>Arduino Webserver</title>"); // Titel der Webseite zwischen Start- und End-Tag
          client.println("</head>"); // End-Tag für Header
          client.print("<body bgcolor='#444444' >"); // Start-Tag für den HTML-Rumpf (Hintergrundfarbe Dunkelgrau)
          client.println("<font size=7, color=\"#FFFFFF\", face=Arial>"); // Start-Tag für Schriftformatierung (Größe, Farbe, Art)
          client.println(tmpValue); // Einfügen des ausgelesenen Temperatur-Werts
          client.println("</font>"); // End-Tag für Schriftformatierung
          client.println("<br>"); // Zeilenumbruch
          client.print("<form method=get>"); // Start-Tag für ein Formular (z.B. für Eingabefelder, Buttons usw.)
          client.print("<input type=submit name=Temperatur value='0'>"); // Button mit Aufschrift '0'
          client.print("<input type=submit name=Temperatur value='1'>"); // Button mit Aufschrift '1'
          client.print("<input type=submit name=Temperatur value='2'>"); // Button mit Aufschrift '2'
          client.print("<input type=submit name=Temperatur value='3'>"); // Button mit Aufschrift '3'
          client.print("<input type=submit name=Temperatur value='4'>"); // Button mit Aufschrift '4'
          client.print("<input type=submit name=Temperatur value='5'>"); // Button mit Aufschrift '5'
          client.print("</form>"); // End-Tag für Formular
          client.println("</body>"); // End-Tag für den HTML-Rumpf
          client.println("</html>"); // End-Tag für die HTML-Datei

          readString=""; // readString-Variable entleeren (für neue Nachrichten vorbereiten)

          client.stop(); // die Client-Verbindung beenden
        }
      }
    }
  }
}
